cheesecake.logger

Package cheesecake :: Module logger |
[hide private]
[frames] | no frames]

## Module logger
source code

Classes | [hide private]
Message |
Producer | Log producer API which sends messages to be logged to a 'consumer' object, which then prints them to stdout, stderr, files, etc.
MultipleProducer |
File |
Path |

Functions | [hide private]
| default_consumer(msg)
| STDOUT(msg)
| STDERR(msg)
| setconsumer(keywords, consumer)

Variables | [hide private]
default |

Function Details | [hide private]

### default_consumer(msg) | source code

### STDOUT(msg) | source code

### STDERR(msg) | source code

### setconsumer(keywords, consumer) | source code

Variables Details | [hide private]

    ### default Value:
        <Producer default>